@@ -194,12 +194,12 @@ momentEstim.baseGmm.twoStep.formula <- function(object, ...)
   if (q == k2 | P$wmatrix == "ident")
     {
     res2 <- .tetlin(dat, w, P$gradv, P$g)
-    z = list(coefficients = res2$par, objective = res2$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df)
+    z = list(coefficients = res2$par, objective = res2$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df, df.residual = (n-k))
     }
   else
-    {
+    {  
     if (P$vcov == "iid")
-    	{
+   	{            
       res1 <- .tetlin(dat, w, P$gradv, P$g, type="2sls")
       initTheta <- res1$par
       gmat <- g(res1$par, dat)
@@ -209,14 +209,14 @@ momentEstim.baseGmm.twoStep.formula <- function(object, ...)
       res2$fsRes <- res1$fsRes
       }
     if (P$vcov == "HAC")
-      {
+      {          
       res1 <- .tetlin(dat, w, P$gradv, P$g, type="2sls")
       initTheta <- res1$par
       gmat <- g(res1$par, dat)
       w <- .myKernHAC(gmat, P)
       res2 <- .tetlin(dat, w, P$gradv, g)
       }
-    z = list(coefficients = res2$par, objective = res2$value, dat=dat, k=k, k2=k2, n=n, q=q, df=df, initTheta = initTheta)	
+    z = list(coefficients = res2$par, objective = res2$value, dat=dat, k=k, k2=k2, n=n, q=q, df=df, initTheta = initTheta, df.residual = (n-k))	
     }
   z$gt <- g(z$coefficients, dat) 
   b <- z$coefficients
@@ -235,7 +235,6 @@ momentEstim.baseGmm.twoStep.formula <- function(object, ...)
   z$g <- P$g
   z$WSpec <- P$WSpec
   z$w0 <- w
-
   names(z$coefficients) <- P$namesCoef
   colnames(z$gt) <- P$namesgt
  
@@ -263,7 +262,7 @@ momentEstim.baseGmm.iterative.formula <- function(object, ...)
   if (q == k2 | P$wmatrix == "ident")
     {
     res <- .tetlin(dat, w, P$gradv, g)
-    z = list(coefficients = res$par, objective = res$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df)
+    z = list(coefficients = res$par, objective = res$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df, df.residual = (n-k))
     }
   else
     {
@@ -298,7 +297,7 @@ momentEstim.baseGmm.iterative.formula <- function(object, ...)
 		cat("Iter :",j,": value=",res$value,", Coef = ", res$par,"\n") 
         j <- j+1	
       }
-    z = list(coefficients = res$par, objective = res$value, dat=dat, k=k, k2=k2, n=n, q=q, df=df, initTheta=initTheta)	
+    z = list(coefficients = res$par, objective = res$value, dat=dat, k=k, k2=k2, n=n, q=q, df=df, initTheta=initTheta, df.residual = (n-k))	
    }
   z$gt <- g(z$coefficients, dat) 
   b <- z$coefficients
@@ -524,7 +523,7 @@ momentEstim.baseGmm.cue.formula <- function(object, ...)
   if (q == k2 | P$wmatrix == "ident")
     {
     res <- .tetlin(dat, w, P$gradv, g)
-    z = list(coefficients = res$par, objective = res$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df)
+    z = list(coefficients = res$par, objective = res$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df, df.residual = (n-k))
     P$weightMessage <- "No CUE needed because the model is just identified"
     }
   else
@@ -569,7 +568,7 @@ momentEstim.baseGmm.cue.formula <- function(object, ...)
       res2$par <- res2$minimum
       res2$value <- res2$objective
       }
-    z = list(coefficients = res2$par, objective = res2$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df, initTheta=initTheta)
+    z = list(coefficients = res2$par, objective = res2$value, dat = dat, k = k, k2 = k2, n = n, q = q, df = df, initTheta=initTheta, df.residual = (n-k))
     if (P$optfct == "optim")
 	z$algoInfo <- list(convergence = res2$convergence, counts = res2$counts, message = res2$message)
     else if(P$optfct == "nlminb")
@@ -909,7 +908,7 @@ momentEstim.fixedW.formula <- function(object, ...)
     }
   
   res2 <- .tetlin(dat, w, P$gradv, g, inv=FALSE)
-  z = list(coefficients = res2$par, objective = res2$value, dat=dat, k=k, k2=k2, n=n, q=q, df=df)	
+  z = list(coefficients = res2$par, objective = res2$value, dat=dat, k=k, k2=k2, n=n, q=q, df=df, df.residual = (n-k))	
 
   z$gt <- g(z$coefficients, dat) 
   b <- z$coefficients
